@@ -32,11 +32,10 @@
 #include <eel/eel-gtk-macros.h>
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-gdk-pixbuf-extensions.h>
-#include <gtk/gtktreednd.h>
-#include <gtk/gtktreesortable.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <libnautilus-private/nautilus-dnd.h>
-#include <glib/gsequence.h>
+#include <glib.h>
 
 enum {
 	SUBDIRECTORY_UNLOADED,
@@ -55,8 +54,9 @@ static guint list_model_signals[LAST_SIGNAL] = { 0 };
 static int fm_list_model_file_entry_compare_func (gconstpointer a,
 						  gconstpointer b,
 						  gpointer      user_data);
-
-static GObjectClass *parent_class;
+static void fm_list_model_tree_model_init (GtkTreeModelIface *iface);
+static void fm_list_model_sortable_init (GtkTreeSortableIface *iface);
+static void fm_list_model_multi_drag_source_init (EggTreeMultiDragSourceIface *iface);
 
 struct FMListModelDetails {
 	GSequence *files;
@@ -95,6 +95,14 @@ struct FileEntry {
 	guint loaded : 1;
 };
 
+G_DEFINE_TYPE_WITH_CODE (FMListModel, fm_list_model, G_TYPE_OBJECT,
+			 G_IMPLEMENT_INTERFACE (GTK_TYPE_TREE_MODEL,
+						fm_list_model_tree_model_init)
+			 G_IMPLEMENT_INTERFACE (GTK_TYPE_TREE_SORTABLE,
+						fm_list_model_sortable_init)
+			 G_IMPLEMENT_INTERFACE (EGG_TYPE_TREE_MULTI_DRAG_SOURCE,
+						fm_list_model_multi_drag_source_init));
+
 static const GtkTargetEntry drag_types [] = {
 	{ NAUTILUS_ICON_DND_GNOME_ICON_LIST_TYPE, 0, NAUTILUS_ICON_DND_GNOME_ICON_LIST },
 	{ NAUTILUS_ICON_DND_URI_LIST_TYPE, 0, NAUTILUS_ICON_DND_URI_LIST },
@@ -287,7 +295,8 @@ fm_list_model_get_value (GtkTreeModel *tree_model, GtkTreeIter *iter, int column
 			zoom_level = fm_list_model_get_zoom_level_from_column_id (column);
 			icon_size = nautilus_get_icon_size_for_zoom_level (zoom_level);
 
-			flags = NAUTILUS_FILE_ICON_FLAGS_USE_THUMBNAILS;
+			flags = NAUTILUS_FILE_ICON_FLAGS_USE_THUMBNAILS |
+				NAUTILUS_FILE_ICON_FLAGS_FORCE_THUMBNAIL_SIZE;
 			if (model->details->drag_view != NULL) {
 				GtkTreePath *path_a, *path_b;
 				
@@ -336,11 +345,6 @@ fm_list_model_get_value (GtkTreeModel *tree_model, GtkTreeIter *iter, int column
 			zoom_level = fm_list_model_get_zoom_level_from_emblem_column_id (column);
 			icon_size = nautilus_get_icon_size_for_zoom_level (zoom_level);
 			emblem_size = nautilus_icon_get_emblem_size_for_icon_size (icon_size);
-			/* Special case default icon size here. This works semi-ok, since we
-			   only show one emblem for the list view anyway */
-			if (emblem_size == 0 && icon_size >= 24) {
-				emblem_size = 16;
-			}
 			if (emblem_size != 0) {
 				emblem_pixbufs = nautilus_file_get_emblem_pixbufs (file,
 										   emblem_size,
@@ -860,10 +864,7 @@ fm_list_model_multi_drag_data_get (EggTreeMultiDragSource *drag_source,
 	context.path_list = path_list;
 
 	if (!drag_target_list) {
-		drag_target_list = gtk_target_list_new 
-			(drag_types, G_N_ELEMENTS (drag_types));
-		gtk_target_list_add_text_targets (
-			drag_target_list, NAUTILUS_ICON_DND_TEXT);
+		drag_target_list = fm_list_model_get_drag_target_list ();
 	}
 
 	if (gtk_target_list_find (drag_target_list,
@@ -1466,12 +1467,15 @@ fm_list_model_set_drag_view (FMListModel *model,
 	model->details->drag_begin_y = drag_begin_y;
 }
 
-void
-fm_list_model_get_drag_types (const GtkTargetEntry **entries,
-			      int *num_entries)
+GtkTargetList *
+fm_list_model_get_drag_target_list ()
 {
-	*entries = drag_types;
-	*num_entries = G_N_ELEMENTS (drag_types);
+	GtkTargetList *target_list;
+
+	target_list = gtk_target_list_new (drag_types, G_N_ELEMENTS (drag_types));
+	gtk_target_list_add_text_targets (target_list, NAUTILUS_ICON_DND_TEXT);
+
+	return target_list;
 }
 
 int               
@@ -1537,8 +1541,8 @@ fm_list_model_dispose (GObject *object)
 		g_hash_table_destroy (model->details->directory_reverse_map);
 		model->details->directory_reverse_map = NULL;
 	}
-	
-	EEL_CALL_PARENT (G_OBJECT_CLASS, dispose, (object));
+
+	G_OBJECT_CLASS (fm_list_model_parent_class)->dispose (object);
 }
 
 static void
@@ -1549,8 +1553,8 @@ fm_list_model_finalize (GObject *object)
 	model = FM_LIST_MODEL (object);
 
 	g_free (model->details);
-	
-	EEL_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
+
+	G_OBJECT_CLASS (fm_list_model_parent_class)->finalize (object);
 }
 
 static void
@@ -1575,8 +1579,6 @@ fm_list_model_class_init (FMListModelClass *klass)
 	attribute_date_modified_q = g_quark_from_static_string ("date_modified");
 	
 	object_class = (GObjectClass *)klass;
-	parent_class = g_type_class_peek_parent (klass);
-
 	object_class->finalize = fm_list_model_finalize;
 	object_class->dispose = fm_list_model_dispose;
 
@@ -1624,57 +1626,6 @@ fm_list_model_multi_drag_source_init (EggTreeMultiDragSourceIface *iface)
 	iface->drag_data_delete = fm_list_model_multi_drag_data_delete;
 }
 
-GType
-fm_list_model_get_type (void)
-{
-	static GType object_type = 0;
-
-	if (object_type == 0) {
-		const GTypeInfo object_info = {
-			sizeof (FMListModelClass),
-			NULL,		/* base_init */
-			NULL,		/* base_finalize */
-			(GClassInitFunc) fm_list_model_class_init,
-			NULL,		/* class_finalize */
-			NULL,		/* class_data */
-			sizeof (FMListModel),
-			0,
-			(GInstanceInitFunc) fm_list_model_init,
-		};
-
-		const GInterfaceInfo tree_model_info = {
-			(GInterfaceInitFunc) fm_list_model_tree_model_init,
-			NULL,
-			NULL
-		};
-
-		const GInterfaceInfo sortable_info = {
-			(GInterfaceInitFunc) fm_list_model_sortable_init,
-			NULL,
-			NULL
-		};
-
-		const GInterfaceInfo multi_drag_source_info = {
-			(GInterfaceInitFunc) fm_list_model_multi_drag_source_init,
-			NULL,
-			NULL
-		};
-		
-		object_type = g_type_register_static (G_TYPE_OBJECT, "FMListModel", &object_info, 0);
-		g_type_add_interface_static (object_type,
-					     GTK_TYPE_TREE_MODEL,
-					     &tree_model_info);
-		g_type_add_interface_static (object_type,
-					     GTK_TYPE_TREE_SORTABLE,
-					     &sortable_info);
-		g_type_add_interface_static (object_type,
-					     EGG_TYPE_TREE_MULTI_DRAG_SOURCE,
-					     &multi_drag_source_info);
-	}
-	
-	return object_type;
-}
-
 void
 fm_list_model_subdirectory_done_loading (FMListModel *model, NautilusDirectory *directory)
 {
