@@ -29,7 +29,9 @@
 
 #include <gdk/gdk.h>
 #include <gio/gio.h>
-#include <bonobo/bonobo-generic-factory.h>
+#include <unique/unique.h>
+#include <libegg/eggsmclient.h>
+#include <dbus/dbus-glib.h>
 #include <libnautilus-private/nautilus-undo-manager.h>
 
 #define NAUTILUS_DESKTOP_ICON_VIEW_IID	"OAFIID:Nautilus_File_Manager_Desktop_Icon_View"
@@ -53,30 +55,29 @@ typedef struct _NautilusSpatialWindow NautilusSpatialWindow;
 typedef struct NautilusShell NautilusShell;
 
 typedef struct {
-	BonoboGenericFactory parent;
+	GObject parent;
+	UniqueApp *unique_app;
+        EggSMClient *smclient;
 	NautilusUndoManager *undo_manager;
-	NautilusShell *shell;
-	gboolean shell_registered;
 	GVolumeMonitor *volume_monitor;
 	unsigned int automount_idle_id;
+	DBusGProxy *ck_session_proxy;
+	gboolean session_is_active;
 } NautilusApplication;
 
 typedef struct {
-	BonoboGenericFactoryClass parent_class;
+	GObjectClass parent_class;
 } NautilusApplicationClass;
 
 GType                nautilus_application_get_type          (void);
 NautilusApplication *nautilus_application_new               (void);
 void                 nautilus_application_startup           (NautilusApplication *application,
 							     gboolean             kill_shell,
-							     gboolean             restart_shell,
 							     gboolean             no_default_window,
 							     gboolean             no_desktop,
 							     gboolean             browser_window,
-							     const char          *startup_id,
 							     const char          *default_geometry,
-							     const char          *session_to_load,
-							     const char          *urls[]);
+							     char               **urls);
 GList *              nautilus_application_get_window_list           (void);
 GList *              nautilus_application_get_spatial_window_list    (void);
 unsigned int         nautilus_application_get_n_windows            (void);
@@ -102,7 +103,7 @@ void                 nautilus_application_close_parent_windows     (NautilusSpat
 void                 nautilus_application_close_all_spatial_windows  (void);
 void                 nautilus_application_open_desktop      (NautilusApplication *application);
 void                 nautilus_application_close_desktop     (void);
-void                 nautilus_application_load_session      (NautilusApplication *application,
-							     const char *filename); 
-char *               nautilus_application_save_session_to_file (void);
+gboolean             nautilus_application_save_accel_map    (gpointer data);
+
+
 #endif /* NAUTILUS_APPLICATION_H */
