@@ -36,10 +36,8 @@
 #include <eel/eel-string.h>
 #include <eel/eel-vfs-extensions.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <gtk/gtkdnd.h>
-#include <gtk/gtkhbox.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include <libgnomeui/gnome-uidefs.h>
 #include <libnautilus-private/nautilus-dnd.h>
 #include <libnautilus-private/nautilus-directory.h>
 #include <libnautilus-private/nautilus-file-dnd.h>
@@ -226,8 +224,8 @@ make_button_box (NautilusInformationPanel *information_panel)
 	gtk_box_pack_start_defaults (GTK_BOX (information_panel->details->container),
 			    	     GTK_WIDGET (information_panel->details->button_box_centerer));
 
-	information_panel->details->button_box = GTK_VBOX (nautilus_keep_last_vertical_box_new (GNOME_PAD_SMALL));
-	gtk_container_set_border_width (GTK_CONTAINER (information_panel->details->button_box), GNOME_PAD);				
+	information_panel->details->button_box = GTK_VBOX (nautilus_keep_last_vertical_box_new (4));
+	gtk_container_set_border_width (GTK_CONTAINER (information_panel->details->button_box), 8);				
 	gtk_widget_show (GTK_WIDGET (information_panel->details->button_box));
 	gtk_box_pack_start (GTK_BOX (information_panel->details->button_box_centerer),
 			    GTK_WIDGET (information_panel->details->button_box),
@@ -264,7 +262,7 @@ nautilus_information_panel_init (NautilusInformationPanel *information_panel)
 	gtk_widget_show (GTK_WIDGET (information_panel->details->title));
 	gtk_box_pack_start (GTK_BOX (information_panel->details->container),
 			    GTK_WIDGET (information_panel->details->title),
-			    FALSE, FALSE, GNOME_PAD);
+			    FALSE, FALSE, 8);
 	
 	/* allocate and install the command button container */
 	make_button_box (information_panel);
@@ -1098,10 +1096,13 @@ loading_uri_callback (NautilusWindowInfo *window,
 		      char               *uri,
 		      NautilusInformationPanel *panel)
 {
+	NautilusWindowSlotInfo *slot;
 	char *title;
 
-	title = nautilus_window_info_get_title (window);
-	nautilus_information_panel_set_uri (panel, 
+	slot = nautilus_window_info_get_active_slot (window);
+
+	title = nautilus_window_slot_info_get_title (slot);
+	nautilus_information_panel_set_uri (panel,
 					    uri,
 					    title);
 	g_free (title);
@@ -1111,6 +1112,7 @@ static void
 nautilus_information_panel_set_parent_window (NautilusInformationPanel *panel,
 					      NautilusWindowInfo *window)
 {
+	gpointer slot;
 	char *title, *location;
 
 	panel->details->window = window;
@@ -1119,9 +1121,11 @@ nautilus_information_panel_set_parent_window (NautilusInformationPanel *panel,
 				 G_CALLBACK (loading_uri_callback), panel, 0);
 	g_signal_connect_object (window, "title_changed",
 				 G_CALLBACK (title_changed_callback), panel, 0);
+
+	slot = nautilus_window_info_get_active_slot (window);
 	
-	title = nautilus_window_info_get_title (window);
-	location = nautilus_window_info_get_current_location (window);
+	title = nautilus_window_slot_info_get_title (slot);
+	location = nautilus_window_slot_info_get_current_location (slot);
 	nautilus_information_panel_set_uri (panel, 
 					    location,
 					    title);
